@@ -29,6 +29,7 @@ from .hvcs import (
     post_changelog,
     upload_to_release,
 )
+from .pre_commit import run_pre_commit, should_run_pre_commit
 from .repository import ArtifactRepo
 from .settings import config, overload_configuration
 from .vcs_helpers import (
@@ -38,6 +39,7 @@ from .vcs_helpers import (
     get_repository_owner_and_name,
     push_new_version,
     tag_new_version,
+    update_additional_files,
     update_changelog_file,
 )
 
@@ -64,6 +66,7 @@ COMMON_OPTIONS = [
     click.option(
         "--patch", "force_level", flag_value="patch", help="Force patch version."
     ),
+    click.option("--prerelease", is_flag=True, help="Creates a prerelease version."),
     click.option("--post", is_flag=True, help="Post changelog."),
     click.option("--retry", is_flag=True, help="Retry the same release, do not bump."),
     click.option(
@@ -90,12 +93,12 @@ def common_options(func):
     return func
 
 
-def print_version(*, current=False, force_level=None, **kwargs):
+def print_version(*, current=False, force_level=None, prerelease=False, **kwargs):
     """
     Print the current or new version to standard output.
     """
     try:
-        current_version = get_current_version()
+        current_version = get_current_version(prerelease)
     except GitError as e:
         print(str(e), file=sys.stderr)
         return False
@@ -105,7 +108,7 @@ def print_version(*, current=False, force_level=None, **kwargs):
 
     # Find what the new version number should be
     level_bump = evaluate_version_bump(current_version, force_level)
-    new_version = get_new_version(current_version, level_bump)
+    new_version = get_new_version(current_version, level_bump, prerelease)
     if should_bump_version(current_version=current_version, new_version=new_version):
         print(new_version, end="")
         return True
@@ -114,7 +117,7 @@ def print_version(*, current=False, force_level=None, **kwargs):
     return False
 
 
-def version(*, retry=False, noop=False, force_level=None, **kwargs):
+def version(*, retry=False, noop=False, force_level=None, prerelease=False, **kwargs):
     """
     Detect the new version according to git log and semver.
 
@@ -127,14 +130,14 @@ def version(*, retry=False, noop=False, force_level=None, **kwargs):
 
     # Get the current version number
     try:
-        current_version = get_current_version()
+        current_version = get_current_version(prerelease)
         logger.info(f"Current version: {current_version}")
     except GitError as e:
         logger.error(str(e))
         return False
     # Find what the new version number should be
     level_bump = evaluate_version_bump(current_version, force_level)
-    new_version = get_new_version(current_version, level_bump)
+    new_version = get_new_version(current_version, level_bump, prerelease)
 
     if not should_bump_version(
         current_version=current_version, new_version=new_version, retry=retry, noop=noop
@@ -192,13 +195,13 @@ def bump_version(new_version, level_bump):
     logger.info(f"Bumping with a {level_bump} version to {new_version}")
 
 
-def changelog(*, unreleased=False, noop=False, post=False, **kwargs):
+def changelog(*, unreleased=False, noop=False, post=False, prerelease=False, **kwargs):
     """
     Generate the changelog since the last release.
 
     :raises ImproperConfigurationError: if there is no current version
     """
-    current_version = get_current_version()
+    current_version = get_current_version(prerelease)
     if current_version is None:
         raise ImproperConfigurationError(
             "Unable to get the current version. "
@@ -232,9 +235,11 @@ def changelog(*, unreleased=False, noop=False, post=False, **kwargs):
             logger.error("Missing token: cannot post changelog to HVCS")
 
 
-def publish(retry: bool = False, noop: bool = False, **kwargs):
+def publish(
+    retry: bool = False, noop: bool = False, prerelease: bool = False, **kwargs
+):
     """Run the version task, then push to git and upload to an artifact repository / GitHub Releases."""
-    current_version = get_current_version()
+    current_version = get_current_version(prerelease)
 
     verbose = logger.isEnabledFor(logging.DEBUG)
     if retry:
@@ -247,7 +252,7 @@ def publish(retry: bool = False, noop: bool = False, **kwargs):
     else:
         # Calculate the new version
         level_bump = evaluate_version_bump(current_version, kwargs.get("force_level"))
-        new_version = get_new_version(current_version, level_bump)
+        new_version = get_new_version(current_version, level_bump, prerelease)
 
     owner, name = get_repository_owner_and_name()
 
@@ -272,8 +277,13 @@ def publish(retry: bool = False, noop: bool = False, **kwargs):
             previous_version=current_version,
         )
 
+        if should_run_pre_commit():
+            logger.info("Running pre-commit command")
+            run_pre_commit()
+
         if not retry:
             update_changelog_file(new_version, changelog_md)
+            update_additional_files()
             bump_version(new_version, level_bump)
         # A new version was released
         logger.info("Pushing new version")
